//alert("apiWrapper");
var _Debug  = false;

//Define exception and error codes
var _NoError = 0;
var _GeneralException = 101;
var _InvalidArgumentError = 201;
var _NotInitialized = 301;
var _NotImplemented = 401;

//local variable definitions
var apiHandle=getAPI();

/*******************************************************************************
**
** Function: LMSInitialize()
** Inputs: None
** Return: CMIBoolean true if the initialization was successful, or
**               CMIBoolean false if the initialization failed.
**
** Description:
** Initialize communication with LMS by calling the LMSInitialize
** function which will be implemented by the LMS.
**
*******************************************************************************/
function LMSInitialize()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSInitialize was not successful.");
      return false;
   }

   var initResult = api.LMSInitialize("");

   if (initResult.toString() != "1")
   {
      var err = ErrorHandler();
   }

   return initResult;
}


/*******************************************************************************
**
** Function LMSFinish()
** Inputs: None
** Return: None
**
** Description:
** Close communication with LMS by calling the LMSFinish
** function which will be implemented by the LMS
**
*******************************************************************************/
function LMSFinish()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSFinish was not successful.");
   }
   else
   {
      // call the LMSFinish function that should be implemented by the API
      api.LMSFinish("");
      var err = ErrorHandler();
   }
   return;
}
/*******************************************************************************/
function LMSGetValue(name)
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSGetValue was not successful.");
	  return null;
   }
   else
   {
     var value = api.LMSGetValue(name);
	 var err = ErrorHandler();
	 if(err != _NoError){
	 	return null;
	 }else{
	 	return value.toString();
	 }
   }
}
/*******************************************************************************/

function LMSSetValue(name, value) 
{
   var api = getAPIHandle();
   if (api == null){
      	alert("Unable to locate the LMSs API Implementation.\nLMSSetValue was not successful.");
   }else{
   		api.LMSSetValue(name,value);
		var err = ErrorHandler();
   }
   return;
}
/*******************************************************************************/

function LMSCommit()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSCommit was not successful.");
   }else{
   		api.LMSCommit("");
		var err = ErrorHandler();
   }
   return;
}
/*******************************************************************************/
function LMSGetLastError() 
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSGetLastError was not successful.");
	  return _GeneralError;;
   }
   return api.LMSGetLastError().toString();
}
/*******************************************************************************/
function LMSGetErrorString(errorCode) 
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSGetErrorString was not successful.");
   }
   return api.LMSGetErrorString(errorCode).toString();

} 
/*******************************************************************************/  
function LMSGetDiagnostic(errorCode) 
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSGetDiagnostic was not successful.");
   }
   return api.LMSDiagnostic(errorCode).toString();
}
/*******************************************************************************/  
function LMSIsInitialized() 
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nLMSIsInitialized failed.");
	  return false;
   }else{
   		var value = api.LMSGetValue("cmi.core.student_name");
		var errCode = api.LMSGetLastError().toString();
		if(errCode==_NotInitialized){
			return false;
		}else{
			return true;
		}
   }
}
/*******************************************************************************/  
function ErrorHandler()
{
   var api = getAPIHandle();
   if (api == null)
   {
      alert("Unable to locate the LMSs API Implementation.\nCannot determine LMS error code.");
	  return;
   }
   var errCode = api.LMSGetLastError().toString();
   if(errCode != _NoError){
   		var errDescription = api.LMSGetErrorString(errCode);
		if(_Debug == true){
			errDescription += "\n";
			errDescription += api.LMSGetDiagnostic(null);
		}
		alert(errDescription);
	}
	return errCode;
}
/*******************************************************************************/  


/******************************************************************************
**
** Function getAPIHandle()
** Inputs: None
** Return: value contained by APIHandle
**
** Description:
** Returns the handle to API object if it was previously set,
** otherwise it returns null
**
*******************************************************************************/
function getAPIHandle()
{
   if (apiHandle == null)
   {
      apiHandle = getAPI();
   }

   return apiHandle;
}


/*******************************************************************************
**
** Function findAPI(win)
** Inputs: win - a Window Object
** Return: If an API object is found, it's returned, otherwise null is returned
**
** Description:
** This function looks for an object named API in the supported window hierarchy
**
*******************************************************************************/

function findAPI(win)
{
	if(_Debug){
		//alert("win is: "+win.location.href);
		alert("findAPI");
	}
	if(win.API != null){
		if(_Debug){
			alert("found api in this window");
		}
		return win.API;
	}
	if(win.length > 0){
		if(_Debug){
			alert("looking for api in windows frames");
		}
		
		for(var i=0; i<win.length; i++){
			if(_Debug){
				alert("looking for api in frames["+i+"]");
			}
			var theAPI = findAPI(win.frames[i]);
			if(theAPI != null){
				return theAPI;
			}
		}
	}
	if(_Debug){
		alert("did not find the api in this window (or its children)");
	}
	return null;
}


/*******************************************************************************
**
** Function getAPI()
** Inputs: none
** Return: If an API object is found, it's returned, otherwise null is returned
**
** Description:
** This function looks for an object named API, first in the current window's 
** frame hierarchy and then, if necessary, in the current window's opener window
** hierarchy (if there is an opener window).
**
*******************************************************************************/
function getAPI()
{
	if(_Debug){
		//alert("win is: "+win.location.href);
		alert("getAPI");
	}
   var theAPI = findAPI(this.top);

   if(theAPI == null)
   {
   		var mytype = typeof(window.opener);
		if(_Debug)
		{
			alert("checking to see if this window has an opener");
			alert("window opener typeof is: "+mytype);
		}
		
		if(mytype != "undefined"){
			if(_Debug){
				alert("checking this windows opener");
			}
			if(this.opener != null){
				if(_Debug){
					alert("this windows opener is not null, checking there");
				}
				theAPI = findAPI(this.opener.top);
				if(_Debug){
					alert('back in getAPI');
				}
				win_opener=this.opener.top;
				if(_Debug){
					alert('just tried to asign win_opener');
				}
			}else{
				if(_Debug){
					alert("this windows opener is null");
				}
			}
		}
   }
   //try again, one level higher...
    if(theAPI == null)
   {
		if(_Debug)
		{
			alert('getAPI, try again, one level higher...')
		}
		
   		mytype = typeof(win_opener.opener);
		if(_Debug)
		{
			alert("checking to see if the windows opener has an opener");
			alert("window opener typeof is: "+mytype);
		}
		
		if(mytype != "undefined"){
			if(_Debug){
				alert("checking the opener's opener");
			}
			if(win_opener.opener != null){
				if(_Debug){
					alert("this openers opener is not null, checking there");
				}
				theAPI = findAPI(win_opener.opener.top);
			}else{
				if(_Debug){
					alert("this openers opener is null");
				}
			}
		}
   }
   return theAPI;
}

